@@ -171,10 +171,11 @@ class _freeze_time(object):
         fake_time = FakeTime(self.time_to_freeze)
         time.time = fake_time
 
-        modules = sys.modules.values()
-        for module in modules:
+        for mod_name, module in list(sys.modules.items()):
             if module is None:
                 continue
+            if mod_name.startswith('six.moves.'):
+                continue
             if hasattr(module, "__name__") and module.__name__ != 'datetime':
                 if hasattr(module, 'datetime') and module.datetime == real_datetime:
                     module.datetime = FakeDatetime
@@ -196,7 +197,7 @@ class _freeze_time(object):
         datetime.date = real_date
         time.time = real_time
 
-        for mod_name, module in sys.modules.items():
+        for mod_name, module in list(sys.modules.items()):
             if mod_name.startswith('six.moves.'):
                 continue
             if mod_name != 'datetime':
